GuppyResponse

Enum GuppyResponse 

pub enum GuppyResponse {
    Success {
        mime: String,
        body: Vec<u8>,
    },
    Prompt {
        text: String,
    },
    Redirect {
        target: String,
    },
    Error {
        message: String,
    },
}
A complete guppy response, as returned by the client.

Variants



Success

A reassembled successful response.

Fields

mime: String
body: Vec<u8>


Prompt

1 <prompt> — repeat the request with user input in the URL query.

Fields

text: String


Redirect

3 <url> — re-request at this (possibly relative) URL.

Fields

target: String


Error

4 <error> — a human-readable error for the user.

Fields

message: String