pub trait Handler:
Send
+ Sync
+ 'static {
// Required method
fn handle(
&self,
request: Request,
) -> impl Future<Output = GuppyResponse> + Send;
}Expand description
The application seam: turn a Request into a GuppyResponse.
Success bodies are chunked, transmitted, and retransmitted by the
server; the other variants go out as single special packets.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".