pub enum GuppyResponse {
Success {
mime: String,
body: Vec<u8>,
},
Prompt {
text: String,
},
Redirect {
target: String,
},
Error {
message: String,
},
}Expand description
A complete guppy response, as returned by the client.
Variants
Success
A reassembled successful response.
Prompt
1 <prompt> — repeat the request with user input in the URL query.
Redirect
3 <url> — re-request at this (possibly relative) URL.
Error
4 <error> — a human-readable error for the user.